@@ -81,6 +81,16 @@ predict.bas = function(object, newdata, se.fit=FALSE, type="link",
       models <- rep(0, nvar+1)
       models[bestmodel+1] <- 1
       if (sum(models) > 1) {
+         if (is.null(eval(object$call$weights))) {
+          object <- bas.lm(eval(object$call$formula),
+                           data=eval(object$call$data), 
+                           n.models=1, alpha=object$g,
+                           initprobs=object$probne0, 
+                           prior=object$prior, modelprior=object$modelprior,
+                           update=NULL,bestmodel=models,
+                           prob.local=.0)
+         }
+        else {
           object <- bas.lm(eval(object$call$formula),
                            data=eval(object$call$data), 
                            weights=eval(object$call$weights),
@@ -89,12 +99,14 @@ predict.bas = function(object, newdata, se.fit=FALSE, type="link",
                            prior=object$prior, modelprior=object$modelprior,
                            update=NULL,bestmodel=models,
                            prob.local=.0)
+        }
           best= which.max(object$postprobs)
           fit  <- as.vector(newX[,object$which[[best]]+1, drop=FALSE] %*% object$mle[[best]]) * object$shrinkage[[best]]
           fit = fit + (1 - object$shrinkage[[best]])*(object$mle[[best]])[1]
           df = df[best]
       }
-      else { fit = rep(nrow(newX), 1) * as.numeric(object$mle[object$size == 1])}
+      else {
+        fit = rep(nrow(newX), 1) * as.numeric(object$mle[object$size == 1])}
       models=bestmodel
       attributes(fit) = list(model = models, best=best)
       
@@ -213,9 +225,10 @@ return(as.vector(yhat))
   shrinkage= object$shrinkage[best]
   if (insample)  xiXTXxiT = hat(object$X[, model+1])  -1/n
   else {
-#    browser()
-    X = cbind(1, X[, model[-1]] )
+
+    X = cbind(1, X[, model[-1], drop=FALSE] )
     oldX = (sweep(object$X[, -1], 2, object$mean.x))[, model[-1]]
+#    browser()
     XRinv = X %*% solve(qr.R(qr(cbind(1,oldX))))
     xiXTXxiT = apply(XRinv^2, 1, sum) -1/n 
   }
